@@ -24,18 +24,15 @@
 #' @export
 #'
 #' @examples
-#' \donttest{
-#' 
+#' \dontrun{
 #' a <- rfg_all_restrooms(accessible = TRUE, unisex = TRUE)
 #' }
-#' 
+#'
 rfg_all_restrooms <- function(accessible = FALSE, unisex = FALSE,
                               verbose = TRUE, tidy = FALSE) {
-  ada_query <- ada_function(accessible)
+  ada_uni <- ada_uni_function(accessible, unisex)
 
-  unisex_query <- unisex_function(unisex)
-
-  query <- paste0(base_url, ".json?", ada_query, unisex_query, "per_page=1")
+  query <- paste0(base_url, ".json?", ada_uni, "&per_page=1")
 
   df <- query_looper(query, verbose, tidy)
 
