@@ -4,7 +4,7 @@
 rfg_tidy <- function(df) {
   df$state <- tolower(trimws(df$state))
 
-  df$state <- case_when(
+  df$state <- dplyr::case_when(
     df$state %in% tolower(state.name) ~ df$state,
     df$state %in% c(
       "washington dc",
